```{include} ../README.md

```

```{toctree}
:maxdepth: 1
:caption: "Contents:"
```

```{toctree}
:caption: Getting started
:name: getting_started
:hidden:
:maxdepth: 1

getting_started/installation
```

```{toctree}
:caption: Usage
:name: usage
:hidden:
:maxdepth: 1

usage/app_cli
usage/snakemake_cli
```
